# coding: utf-8

import logging.config

from collections import defaultdict

from tionix_scheduler_client.settings_handler import (
    update_global_from_settings, update_module_settings)

PROTOCOL = 'http'
HOST = 'localhost'
PORT = '10001'

LOG_LEVEL = 'INFO'

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s.%(msecs)03d %(process)d %(levelname)s '
                      '%(name)s [-] %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S',
        },
        'extended': {
            'format': '%(asctime)s - %(levelname)s - File: %(filename)s - '
                      '%(funcName)s() - Line: %(lineno)d - %(message)s'
        }
    },
    'handlers': {
        'null': {
            'class': 'logging.NullHandler',
        },
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default',
        }
    },
    'loggers': {
        '': {
            'handlers': ['console']
        },
        '__main__': {
            'handlers': ['console']
        }
    }
}

logging.config.dictConfig(LOGGING)
logging.getLogger().setLevel(LOG_LEVEL)

base_config_path = '/etc/tionix/tionix.yaml'
module_config_path = '/etc/tionix/scheduler_client.yaml'

module_settings = defaultdict(dict)
gl = globals()

update_module_settings(
    module_settings, gl, module_config_path, base_config_path)

# Have to update log level before updating other variables for
# proper logger output
if module_settings['LOG_LEVEL']:
    logging.getLogger().setLevel(module_settings['LOG_LEVEL'])

update_global_from_settings(module_settings, gl)

logging.getLogger().setLevel(LOG_LEVEL)

if HOST.lower().startswith('http://'):
    SCHEDULER_URL = '{0}:{1}'.format(HOST, PORT)
else:
    SCHEDULER_URL = '{0}://{1}:{2}'.format(PROTOCOL, HOST,
                                           PORT)
